@@ -5,7 +5,7 @@ from matplotlib import pyplot as plt
   
   
 # read the image 
-img = cv2.imread('files/img/stacked_bond.png') 
+img = cv2.imread('files/img/Tischbank.jpg') 
   
 # convert image to gray scale image 
 gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY) 
